@@ -2,12 +2,12 @@ from copy import deepcopy
 from django.conf import settings
 from django.contrib.admin.widgets import AdminSplitDateTime, AdminDateWidget
 from django.forms.models import modelform_factory
-from django.forms.widgets import FileInput
 from django.template.loader import render_to_string
 from django.utils import simplejson
-from django.utils.importlib import import_module
+
 from django.utils.translation import ugettext
 
+from inplaceeditform.commons import  import_module
 from inplaceeditform.commons import has_transmeta, apply_filters
 
 
@@ -90,7 +90,7 @@ class BaseAdaptorField(object):
         return self.empty_value()
 
     def empty_value(self):
-        return ugettext('Dobleclick to edit')
+        return getattr(settings, 'INPLACEEDIT_EDIT_EMPTY_VALUE', ugettext('Dobleclick to edit'))
 
     def render_field(self, template_name="inplaceeditform/render_field.html", extra_context=None):
         extra_context = extra_context or {}
@@ -172,7 +172,9 @@ class BaseAdaptorField(object):
                 self.field_name = transmeta.get_real_fieldname(self.field_name)
                 self.transmeta = True
                 if not self.render_value(self.field_name):
-                    self.initial = {self.field_name: ugettext('Write a traslation')}
+                    message_translation = getattr(settings, 'INPLACEEDIT_EDIT_MESSAGE_TRANSLATION',
+                                                  ugettext('Write a traslation'))
+                    self.initial = {self.field_name: message_translation}
                 return
         self.transmeta = False
 
@@ -281,7 +283,7 @@ class AdaptorDateTimeField(BaseDateField):
 
 class AdaptorChoicesField(BaseAdaptorField):
 
-    MULTIPLIER_HEIGHT = 1.5
+    MULTIPLIER_HEIGHT = 1.75
     INCREASE_WIDTH = 40
 
     @property
@@ -301,7 +303,7 @@ class AdaptorChoicesField(BaseAdaptorField):
 
 class AdaptorForeingKeyField(BaseAdaptorField):
 
-    MULTIPLIER_HEIGHT = 1.5
+    MULTIPLIER_HEIGHT = 1.75
     INCREASE_WIDTH = 40
 
     @property
@@ -377,8 +379,11 @@ class AdaptorFileField(BaseAdaptorField):
         return "%spx" % (self.font_size * self.MULTIPLIER_HEIGHT)
 
     def render_field(self, template_name="inplaceeditform/adaptor_file/render_field.html"):
-        from django.core.context_processors import csrf
-        extra_context = csrf(self.request)
+        try:
+            from django.core.context_processors import csrf
+            extra_context = csrf(self.request)
+        except ImportError:
+            extra_context = {}
         return super(AdaptorFileField, self).render_field(template_name, extra_context)
 
     def render_media_field(self, template_name="inplaceeditform/adaptor_file/render_media_field.html"):
@@ -395,14 +400,12 @@ class AdaptorFileField(BaseAdaptorField):
         config.update(context)
         return render_to_string(template_name, config)
 
+    def save(self, value):
+        getattr(self.obj, self.field_name).save(value.name, value)
+
 
 class AdaptorImageField(AdaptorFileField):
 
-    def get_field(self):
-        field = super(AdaptorImageField, self).get_field()
-        field.field.widget = FileInput()
-        return field
-
     def render_field(self, template_name="inplaceeditform/adaptor_image/render_field.html"):
         return super(AdaptorImageField, self).render_field(template_name)
 
